@@ -146,22 +146,28 @@ class CollectionSerializer(Serializer):
         if db_links:
             collection_links += resolve_links(db_links, base_url)
 
-        stac_extensions = db_model.stac_extensions or []
-
-        return stac_types.Collection(
+        collection = stac_types.Collection(
             type="Collection",
             id=db_model.id,
-            stac_extensions=stac_extensions,
             stac_version=db_model.stac_version,
-            title=db_model.title,
             description=db_model.description,
-            keywords=db_model.keywords,
             license=db_model.license,
-            providers=db_model.providers,
-            summaries=db_model.summaries,
             extent=db_model.extent,
             links=collection_links,
         )
+        # We need to manually include optional values to ensure they are
+        # excluded if we're not using response models.
+        if db_model.stac_extensions:
+            collection["stac_extensions"] = db_model.stac_extensions
+        if db_model.title:
+            collection["title"] = db_model.title
+        if db_model.keywords:
+            collection["keywords"] = db_model.keywords
+        if db_model.providers:
+            collection["providers"] = db_model.providers
+        if db_model.summaries:
+            collection["summaries"] = db_model.summaries
+        return collection
 
     @classmethod
     def stac_to_db(
